# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)

# ------------------------------------ Temperature and activity --------------------------------------
# read the temp data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
tdata<-read.csv2("small_activity2.csv",sep=";",header=T, fill = T) 


# make a graph that shows the time of day on the x axis
# the activity on the y axis
# and temperature on the third axis

# I did net test between 12 and 15
# so no temperature data available
# get it from the internet and change colour
# https://weatherspark.com/m/95256/2/Average-Weather-in-February-in-Johannesburg-South-Africa

t1<-ggplot(data=tdata, aes(x=Time, y=Total_activity)) +
  geom_bar(stat = "identity", fill = "skyblue1") +
  geom_line(aes(x = Time, y = 7*Test_temp), size = 1.5, color="tomato1", group = 1) +
  geom_line(aes(x = Time, y = 7*Test_tempp), linetype = "dotted", size = 1.5, color="black", group = 1) + # the website weather
  geom_line(aes(x = Time, y = 7*Test_temppp), size = 1.5, color="tomato1", group = 1) +
  scale_y_continuous(sec.axis = sec_axis(~./7, name = "Average temperature per hour")) +
  labs(title="Activity pattern", 
       x="Time (h)", y = "Activity time (s)")+
  theme(plot.title = element_text(hjust = 0.5))
t1

# as you can see I tried to do as many tests as possible beneath 25 degrees


# make another graph but not with time, but with date
# use for this the daily temperature instead of exact time temperature
# read another small dataset
ddata<-read.csv2("small_daily.csv",sep=";",header=T, fill = T)

t2<-ggplot(data=ddata, aes(x=Day, y=Avg_activity)) +
  geom_bar(stat = "identity", fill = "skyblue1") +
  geom_line(aes(x = Day, y = 7*Daily_temp), size = 1.5, color="orangered3", group = 1) +
  geom_line(aes(x = Dayy, y = 7*Daily_temp), size = 1.5, color="tomato1", group = 1) + # the website weather
  scale_y_continuous(sec.axis = sec_axis(~./7, name = "Average temperature per hour")) +
  labs(title="Activity pattern", 
       x="Day measured", y = "Activity time (s)")+
  theme(plot.title = element_text(hjust = 0.5))
t2

# you see many differences between the days
# no consistent change (so also not between the areas)

plot_grid(t1, t2, labels = c("A", "B"), ncol = 1, nrow = 2)


# look at the amount of tests per hour
tdata2<-read.csv2("small_activity_test.csv",sep=";",header=T, fill = T) 


# make a graph that shows the time of day on the x axis
# the activity on the y axis
# and temperature on the third axis

t3<-ggplot(data=tdata2, aes(x=Time, y=Amount_tests)) +
  geom_bar(stat = "identity", fill = "skyblue1") +
  geom_line(aes(x = Time, y = 1*Test_temp), size = 1.5, color="tomato1", group = 1) +
  geom_line(aes(x = Time, y = 1*Test_tempp), linetype = "dotted", size = 1.5, color="black", group = 1) + # the website weather
  geom_line(aes(x = Time, y = 1*Test_temppp), size = 1.5, color="tomato1", group = 1) +
  scale_y_continuous(sec.axis = sec_axis(~./1, name = "Average temperature per hour\n")) +
  labs(title="Testing hours", 
       x="\nTime (h)", y = "Number of tests\n")+
  theme(axis.text=element_text(size=13),
        axis.title=element_text(size=18)) +
  theme(plot.title = element_text(size= 22, hjust = 0.5))
t3
