# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)
# ------------------------------------- loading in data -------------------------------------------- 

remove(list=ls())
# set the working directory
setwd("C:/Users/nynke/OneDrive/Documenten/South Africa/data_archive/R")

# read the sound data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
sodata<-read.csv2("Sound_data.csv",sep=";",header=T, fill = T) 

wmdata<-read.csv2("cswdata.csv", sep = ";", header = T, fill = T)

# apparently some empty rows are added in the bottom
# remove them
wmdata <- wmdata[-c(62, 63, 64), ]

# ------------------------------------- look at the data -------------------------------------------
#View(sodata)
names(sodata)

# remove columns that you for sure do not need
# sound: column 21, 22, 30, 42
# scent: column 20, 21, 29, 41
sodata <- sodata[,c(1:20, 26:30, 32:42, 44:47)] # this shows all the columns I want to keep
names(sodata)
# rename columns so you can easily combine the data
colnames(sodata)
colnames(sodata)[2] <- "Individual"
colnames(sodata)[3] <- "Test_nr"
colnames(sodata)[13] <- "More_20m"
colnames(sodata)[14] <- "Between_10_20m"
colnames(sodata)[15] <- "Less_10m"
colnames(sodata)[20] <- "Min_distance"
colnames(sodata)[23] <- "Time_more_20m"
colnames(sodata)[24] <- "Time_10_20m"
colnames(sodata)[25] <- "Time_less_10m"
colnames(sodata)[37] <- "Hes_far"
colnames(sodata)[38] <- "Hes_close"

# make factors
sodata$Area <- as.factor(sodata$Area)
sodata$Individual <- as.factor(sodata$Individual)
sodata$Test_nr <- as.factor(sodata$Test_nr)
sodata$Sex <- as.factor(sodata$Sex)
sodata$Partner <- as.factor(sodata$Partner)
sodata$Test_sound <- as.factor(sodata$Test_sound)
sodata$Test_model <- as.factor(sodata$Test_model)
sodata$Test_temp <- as.factor(sodata$Test_temp)
sodata$Daily_temp <- as.factor(sodata$Daily_temp)
sodata$Date <- as.factor(sodata$Date)

# remove the individuals from the dataset with only 1 test. 
sodata <- sodata[-c(31, 32), ]


# -------------------------------- correlation matrix sound----------------------------------------
library(xts)
library(zoo)
library(PerformanceAnalytics)
my_data <- sodata[, c(15,25,39,40)]
chart.Correlation(my_data, histogram=TRUE, pch=19)

my_data <- wmdata[, c(15,21,35,36)]
chart.Correlation(my_data, histogram=TRUE, pch=19)


ashiadata1 <- sodata[1:30, ]
my_data2 <- ashiadata1[, c(15,25,39,40)]
chart.Correlation(my_data2, histogram=TRUE, pch=19)

kuzukodata1 <- sodata[31:64, ]
my_data3 <- kuzukodata1[, c(15,25,39,40)]
chart.Correlation(my_data3, histogram=TRUE, pch=19)



# -------------------------------- correlation matrix scent ----------------------------------------
scdata<-read.csv2("Scent_data.csv",sep=";",header=T, fill = T) 

# ------------------------------------- look at the data -------------------------------------------
#View(sodata)
names(scdata)

# remove columns that you for sure do not need
# scent: column 20, 21, 29, 41
scdata <- scdata[,c(1:19, 27:29, 31:41, 43:46)] # this shows all the columns I want to keep
names(scdata)
# rename columns so you can easily combine the data
colnames(scdata)
colnames(scdata)[2] <- "Individual"
colnames(scdata)[3] <- "Test_nr"
colnames(scdata)[11] <- "More_20m"
colnames(scdata)[12] <- "Between_10_20m"
colnames(scdata)[13] <- "Less_10m"
colnames(scdata)[19] <- "Min_distance"
colnames(scdata)[20] <- "Time_more_20m"
colnames(scdata)[21] <- "Time_10_20m"
colnames(scdata)[22] <- "Time_less_10m"
colnames(scdata)[34] <- "Hes_far"
colnames(scdata)[35] <- "Hes_close"

# make factors
scdata$Area <- as.factor(scdata$Area)
scdata$Individual <- as.factor(scdata$Individual)
scdata$Test_nr <- as.factor(scdata$Test_nr)
scdata$Sex <- as.factor(scdata$Sex)
scdata$Partner <- as.factor(scdata$Partner)
scdata$Test_scent <- as.factor(scdata$Test_scent)
scdata$Test_temp <- as.factor(scdata$Test_temp)
scdata$Daily_temp <- as.factor(scdata$Daily_temp)
scdata$Date <- as.factor(scdata$Date)

# remove the individuals from the dataset with only 1 test. 
scdata <- scdata[-c(11, 22), ]

kuzukodata2 <- scdata[29:56, ]

my_data4 <- kuzukodata2[, c(13,22,36,37)]
chart.Correlation(my_data4, histogram=TRUE, pch=19)

citation("rptR")
