# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)
# ------------------------------------- loading in data -------------------------------------------- 

remove(list=ls())
# set the working directory
setwd("C:/Users/nynke/Documents/South Africa/data_archive/R")

# read the sound data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
wmdata<-read.csv2("cswdata.csv", sep = ";", header = T, fill = T)

# apparently some empty rows are added in the bottom
# remove them
wmdata <- wmdata[-c(62, 63, 64), ]


# repeatability
library(rptR)
ressound <- rpt(Less_10m ~ (1|Individual), 
                grname = "Individual", 
                data = wmdata, datatype = "Binary", nboot = 1000, npermut = 0)
print(ressound)

ressound2 <- rpt(Time_less_10m ~ (1|Individual), 
                 grname = "Individual", 
                 data = wmdata, datatype = "Gaussian", nboot = 1000, npermut = 0)
print(ressound2)

ressound3 <- rpt(Hes_prese0t ~ (1|Individual), 
                 grname = "Individual", 
                 data = wmdata, datatype = "Binary", nboot = 1000, npermut = 0)
print(ressound3)

ressound4 <- rpt(Total_hes ~ (1|Individual), 
                 grname = "Individual", 
                 data = wmdata, datatype = "Poisson", nboot = 1000, npermut = 0)
print(ressound4)
# R individual link-scale = 0.166
# R individual original scale = 0.029
# it is still a little low, but could be due to a lack of individuals
# P value is 0.21 --> not significant. Again could be due to the lack of tests
# could also be that the response is not an individual trait, but that it could be due to learning, or copying

ressound5 <- rpt(E_S_T ~ (1|Individual), 
                 grname = "Individual", 
                 data = wmdata, datatype = "Poisson", nboot = 1000, npermut = 0)
print(ressound5)

#calculate mean
mean(wmdata$Less_10m)
mean(wmdata$Time_less_10m)
mean(wmdata$Hes_prese0t)
mean(wmdata$Total_hes)
mean(wmdata$E_S_T)

#calculate SE
#SD/sqrt(N)
sd(wmdata$Less_10m)/sqrt(length(wmdata$Less_10m))
sd(wmdata$Time_less_10m)/sqrt(length(wmdata$Time_less_10m))
sd(wmdata$Hes_prese0t)/sqrt(length(wmdata$Hes_prese0t))
sd(wmdata$Total_hes)/sqrt(length(wmdata$Total_hes))
sd(wmdata$E_S_T)/sqrt(length(wmdata$E_S_T))

# calculate CV
#(SD/mean)*100
(sd(wmdata$Less_10m) / mean(wmdata$Less_10m)) * 100
(sd(wmdata$Time_less_10m) / mean(wmdata$Time_less_10m)) * 100
(sd(wmdata$Hes_prese0t) / mean(wmdata$Hes_prese0t)) * 100
(sd(wmdata$Total_hes) / mean(wmdata$Total_hes)) * 100
(sd(wmdata$E_S_T) / mean(wmdata$E_S_T)) * 100
