# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)
# ------------------------------------- loading in data -------------------------------------------- 

remove(list=ls())
# set the working directory
setwd("C:/Users/nynke/OneDrive/Documenten/South Africa/data_archive/R")

# read the sound data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
wmdata<-read.csv2("cswdata.csv", sep = ";", header = T, fill = T)

# apparently some empty rows are added in the bottom
# remove them
wmdata <- wmdata[-c(62, 63, 64), ]

# make datasets for just captive, semi or wild
attach(wmdata)
names(wmdata)
DatA2=droplevels(subset(wmdata, Area=="Captive"))
DatS2=droplevels(subset(wmdata, Area=="Semi"))
DatW2=droplevels(subset(wmdata, Area=="Wild"))

# this dataset is for learning



#  ------------------ check for the presence at <10m -------------
# use the subset sodataY to see if the amount of "Y" decreases per test
# I made a small data set to help with this
smalldata1<-read.csv2("sound_small.csv",sep=";",header=T, fill = T)
smalldata1$Test_nr <- as.factor(smalldata1$Test_nr)


l1<-ggplot(data=smalldata1, aes(x=Area, y=Per_less, fill=Test_nr)) + ylim(0,100) +
  geom_bar(stat="identity", position=position_dodge())+
  #  geom_text(aes(label=Test_nr), vjust=1.5, color="black",
  #            position = position_dodge(0.9), size=3.5)+
  scale_fill_brewer(palette="Greys")+
  theme_minimal() +
  labs(title="Presence at <10m", 
       x="Test", y = "Proportion at <10m (%)")+ 
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(axis.text = element_text(size=15)) +
  theme(axis.title = element_text(size=20))

l1


# ----------- time spent <10m --------------
# only the individuals that came <10m at least once
# use this new dataset, based om wmdata
# but with only individuals within 10m
# and with added empty rows to make sure these 0's do appear in the graphs
soy<-read.csv2("SOdataY2.csv",sep=";",header=T, fill = T)
soy$Test_nr <- as.factor(soy$Test_nr)

boxtimec<-plyr::ddply(soy,c("Area","Test_nr"), summarise, N=length(Time_less_10m),mean_div=mean(Time_less_10m,na.rm=T),sd_div=sd(Time_less_10m,na.rm = T),se_div=sd_div/sqrt(N))
boxtimec
l2<-ggplot(boxtimec, aes(x=Area, y=mean_div, fill=Test_nr))+ ylim(0,900) +
  geom_bar(stat = "identity", position = "dodge")+geom_errorbar(aes(ymin=mean_div-se_div, ymax=mean_div+se_div), width = 0.2, position=position_dodge(.9))+
  labs(x="Tests per area", y="Time spent <10m") +
  theme_classic(base_size=14) +
  labs(title = "Time spent <10m",
       x="Test", y="Mean time spent <10m ( SE)")+
  scale_fill_brewer(palette="Greys") + theme_minimal() +
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(axis.text = element_text(size=15)) +
  theme(axis.title = element_text(size=20))
l2



# ------------ hesitation presence -----------------


l3<-ggplot(data=smalldata1, aes(x=Area, y=Per_hes, fill=Test_nr)) + ylim(0,90) +
  geom_bar(stat="identity", position=position_dodge())+
  #  geom_text(aes(label=Per_hes), vjust=1.6, color="black",
  #            position = position_dodge(0.9), size=3.5)+
  scale_fill_brewer(palette="Greys")+
  theme_minimal() +
  labs(title="Hesitation present", 
       x="Test", y = "Proportion of hesitation (%)")+ 
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(axis.text = element_text(size=15)) +
  theme(axis.title = element_text(size=20))
l3



# ---------- total hesitation ------------
wmdata$Test_nr <- as.factor(wmdata$Test_nr)

boxhes<-plyr::ddply(wmdata,c("Area","Test_nr"), summarise, N=length(Total_hes),mean_div=mean(Total_hes,na.rm=T),sd_div=sd(Total_hes,na.rm = T),se_div=sd_div/sqrt(N))
boxhes
l4<-ggplot(boxhes, aes(x=Area, y=mean_div, fill=Test_nr))+ ylim(0,9) +
  geom_bar(stat = "identity", position = "dodge")+geom_errorbar(aes(ymin=mean_div-se_div, ymax=mean_div+se_div), width = 0.2, position=position_dodge(.9))+
  labs(x="Tests per area", y="Total hesitation present") +
  theme_classic(base_size=14) +
  labs(title = "Total hesitation",
       x="Test", y="Mean amount of hesitation ( SE)")+
  scale_fill_brewer(palette="Greys") + theme_minimal() +
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(axis.text = element_text(size=15)) +
  theme(axis.title = element_text(size=20))
l4

# combine all
plot_grid(l1, l2, l3, l4, labels = c("A", "B", "C", "D"), ncol = 2, nrow = 2)
