# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)
# ------------------------------------- loading in data -------------------------------------------- 

remove(list=ls())
# set the working directory
setwd("C:/Users/nynke/OneDrive/Documenten/South Africa/data_archive/R")

# read the sound data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
wmdata<-read.csv2("cswdata.csv", sep = ";", header = T, fill = T)

# apparently some empty rows are added in the bottom
# remove them
wmdata <- wmdata[-c(62, 63, 64), ]

# make datasets for just captive, semi or wild
attach(wmdata)
names(wmdata)
DatA2=droplevels(subset(wmdata, Area=="Captive"))
DatS2=droplevels(subset(wmdata, Area=="Semi"))
DatW2=droplevels(subset(wmdata, Area=="Wild"))

# this datafile checks for differences between captive, semi and wild
# with different treatments: control vs lion

# ---------------- start with presence <10m ----------------
# create dataset based on wmdata
# again % so no SE's
YControl <- c(46, 17, 0)
YLion <- c(64, 10, 33)
Area <- c("Captive", "Semi", "Wild")
dfp10 <- data.frame(YControl, YLion, Area)
dfp10_1 <- melt(dfp10, id.vars='Area')
head(dfp10_1) # now you see it made 3 columns

# graph it
Treatment=c("Control","Lion", "Control", "Lion", "Control", "Lion")
Area = c("Captive", "Captive", "Semi", "Semi", "Wild", "Wild")

# grob <- grobTree(textGrob("P = ", x=0.60,  y=0.85, hjust=0,
#                          gp=gpar(col="black", fontsize=20, fontface="italic"))) # to add the p value as a text in the graph
# grob is to add the P value into the graph

p1<-ggplot(dfp10_1, aes(x=Area, y=value, fill=Treatment)) + ylim(0,70) +
  geom_bar(position = "dodge", stat='identity') +  # the y axis is a % of all the times <10 happens within an area
  #  geom_text(aes(label=value), vjust=1.6, color="black",
  #            position = position_dodge(0.9), size=4.5) +
  scale_fill_manual(values = c("gray21", "gray70")) +
  labs(title="Individual presence within 10m", 
       x=" ", y = "Presence <10m (%)")+ 
  #  annotation_custom(grob) + # p value 
  theme(plot.title = element_text(hjust = 0.5, size = 30)) +
  theme(axis.text = element_text(size=20)) +
  theme(axis.title = element_text(size=25))
p1

# compare the sounds between the areas
newdata <- subset(wmdata, Test_sound == "Lion")
glm13=glmer(newdata$Less_10m~newdata$Area+(1|newdata$Individual), family = poisson)
summary(glm13)

newdata2 <- subset(wmdata, Test_sound == "Control")
glm14=glmer(newdata2$Less_10m~newdata2$Area+(1|newdata2$Individual), family = poisson)
summary(glm14)

# compare the sounds within the areas
newdata <- subset(wmdata, Area == "Captive")
glm13=glmer(newdata$Less_10m~newdata$Test_sound+(1|newdata$Individual), family = poisson)
summary(glm13)

newdata2 <- subset(wmdata, Area == "Wild")
glm14=glmer(newdata2$Less_10m~newdata2$Test_sound+(1|newdata2$Individual), family = poisson)
summary(glm14)

newdata3 <- subset(wmdata, Area == "Semi")
glm15=glmer(newdata3$Less_10m~newdata3$Test_sound+(1|newdata3$Individual), family = poisson)
summary(glm15)


# ----------- time <10m ------------------------
# only the individuals that came <10m at least once
wmdataY=subset(wmdata, Less_10m=="1")

# calculate the means for the captive population
DatA2=droplevels(subset(wmdataY, Area=="Captive"))
Time10=split(DatA2$Time_less_10m,DatA2$Test_sound)
MeanTime10=sapply(Time10, mean); MeanTime10
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDTime10=sapply(Time10, sd)
nTime10 = sapply(Time10, length)
#SE=SD/Sqrt(n)
SETime10=SDTime10/sqrt(nTime10)

# Semi
# calculate the means for the semi wild population
DatS2=droplevels(subset(wmdataY, Area=="Semi"))
Time10S=split(DatS2$Time_less_10m,DatS2$Test_sound)
MeanTime10S=sapply(Time10S, mean); MeanTime10S
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDTime10S=sapply(Time10S, sd)
nTime10S = sapply(Time10S, length)
#SE=SD/Sqrt(n)
SETime10S=SDTime10S/sqrt(nTime10S)


# Wild
# calculate the means for the wild population
DatW2=droplevels(subset(wmdataY, Area=="Wild"))
# this dataset should show that the 2 wild individuals came within 10m 4 times
# even though this is just 2 time during the lion trials
# 0 times during control
# however, in order to add the control to the graph, I added a 1 to the presence at 10m control trials
# but the time spent threre still stands at 0 seconds

Time10W=split(DatW2$Time_less_10m,DatW2$Test_sound)
MeanTime10W=sapply(Time10W, mean); MeanTime10W
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDTime10W=sapply(Time10W, sd)
nTime10W = sapply(Time10W, length)
#SE=SD/Sqrt(n)
SETime10W=SDTime10W/sqrt(nTime10W)

Treatment=c("Control","Lion", "Control", "Lion", "Control", "Lion")
Area = c("Captive", "Captive", "Semi", "Semi", "Wild", "Wild")

# Put all numbers of captive and wild in a column
Means10=c(MeanTime10,MeanTime10S, MeanTime10W)
SDs10=c(SDTime10,SDTime10S,SDTime10W)
SEs10=c(SETime10,SETime10S,SETime10W)
Ns10=c(nTime10,nTime10S,nTime10W)


# Make a complete dataframe of both populations
dfa_T10=data.frame(Area,Treatment,Means10,SDs10,SEs10,Ns10)
dfa_T10

# graph it
p2 <- ggplot(dfa_T10, aes(x = Area, y = Means10, fill = Treatment)) +
  geom_bar(stat = "identity", position = "dodge") +
  geom_errorbar(aes(ymin=Means10-SEs10, ymax=Means10+SEs10), width = 0.2, position=position_dodge(.9))+
  scale_fill_manual(values = c("Gray21", "Gray70")) +
  labs(title="Time spent within 10m ",
       x="", y = "Time <10m (s) (SE)")+ 
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(plot.subtitle = element_text(hjust = 0.5, size = 20)) +
  theme(axis.text = element_text(size=20)) +
  theme(axis.title = element_text(size=22))
p2


# ---------------- evidence of hesitation -----------------
# create dataset based om wmdata
YControl <- c(54, 33, 0)
YLion <- c(64, 10, 33)
Area <- c("Captive", "Semi", "Wild")
dfh2 <- data.frame(YControl, YLion, Area)
dfh2_1 <- melt(dfh2, id.vars='Area')
head(dfh2_1) # now you see it made 3 columns

Treatment=c("Control","Lion", "Control", "Lion", "Control", "Lion")
Area = c("Captive", "Captive", "Semi", "Semi", "Wild", "Wild")



# graph it
# grob3 <- grobTree(textGrob("P = ", x=0.6,  y=0.85, hjust=0,
#                           gp=gpar(col="black", fontsize=20, fontface="italic"))) # to add the p value as a text in the graph

p3<-ggplot(dfh2_1, aes(x=Area, y=value, fill=Treatment)) + ylim(0,70) +
  geom_bar(position = "dodge", stat='identity') + 
  #  geom_text(aes(label=value), vjust=1.6, color="black",
  #            position = position_dodge(0.9), size=4.5) +
  scale_fill_manual(values = c("Gray21","Gray70")) +
  labs(title="Evidence of hesitation", 
       x="Area", y = "Individuals hesitating (%)")+
  #  annotation_custom(grob3) + # p value 
  theme(plot.title = element_text(hjust = 0.5, size = 30)) +
  theme(axis.text = element_text(size=20)) +
  theme(axis.title = element_text(size=25))
p3

# ----------------- frequency of hesitation ---------------------
# calculate the means for the captive population
DatA3=droplevels(subset(wmdata, Area=="Captive"))
hes=split(DatA3$Time_less_10m,DatA3$Test_sound)
Meanhes=sapply(hes, mean); Meanhes
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDhes=sapply(hes, sd)
nhes = sapply(hes, length)
#SE=SD/Sqrt(n)
SEhes=SDhes/sqrt(nhes)

# Semi
# calculate the means for the semi wild population
DatS3=droplevels(subset(wmdata, Area=="Semi"))
hesS=split(DatS3$Time_less_10m,DatS3$Test_sound)
MeanhesS=sapply(hesS, mean); MeanhesS
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDhesS=sapply(hesS, sd)
nhesS = sapply(hesS, length)
#SE=SD/Sqrt(n)
SEhesS=SDhesS/sqrt(nhesS)


# Wild
# calculate the means for the wild population
DatW3=droplevels(subset(wmdata, Area=="Wild"))

hesW=split(DatW3$Time_less_10m,DatW3$Test_sound)
MeanhesW=sapply(hesW, mean); MeanhesW
# op dezelfde manier kun SD en sampesizes uitrekenen, en daarmee kan je SE uitrekenen
SDhesW=sapply(hesW, sd)
nhesW = sapply(hesW, length)
#SE=SD/Sqrt(n)
SEhesW=SDhesW/sqrt(nhesW)

Treatment=c("Control","Lion", "Control", "Lion", "Control", "Lion")
Area = c("Captive", "Captive", "Semi", "Semi", "Wild", "Wild")

# Put all numbers of captive and wild in a column
Meansh=c(Meanhes,MeanhesS, MeanhesW)
SDsh=c(SDhes,SDhesS,SDhesW)
SEsh=c(SEhes,SEhesS,SEhesW)
Nsh=c(nhes,nhesS,nhesW)


# Make a complete dataframe of both populations
dfa_H=data.frame(Area,Treatment,Meansh,SDsh,SEsh,Nsh)
dfa_H

# graph it
p4 <- ggplot(dfa_H, aes(x = Area, y = Meansh, fill = Treatment)) +
  geom_bar(stat = "identity", position = "dodge") +
  geom_errorbar(aes(ymin=Meansh-SEsh, ymax=Meansh+SEsh), width = 0.2, position=position_dodge(.9))+
  scale_fill_manual(values = c("Gray21", "Gray70")) +
  labs(title="Recurrence of hesitation",
       x="", y = "Frequency of hesitation (SE)")+ 
  theme(plot.title = element_text(hjust = 0.5, size = 25)) +
  theme(plot.subtitle = element_text(hjust = 0.5, size = 20)) +
  theme(axis.text = element_text(size=20)) +
  theme(axis.title = element_text(size=22))
p4

# combine all
plot_grid(p1, p2, p3, p4, labels = c("A", "B", "C", "D"), ncol = 2, nrow = 2)
