# ----------------------------------------- libraries ----------------------------------------------
library(ggplot2)
library(magrittr)
library(ggpubr)
library(plyr)
library(dplyr)
library(rptR)
library(car)
library(Matrix)
library(lme4)
library(stats)
library(lmerTest)
library(grid)
library(gridExtra)
library(reshape2)
library(cowplot)
# ------------------------------------- loading in data -------------------------------------------- 

remove(list=ls())
# set the working directory
setwd("C:/Users/nynke/OneDrive/Documenten/South Africa/data_archive/R")

# read the sound data
# write the name of the file, sep means how the numbers of the data are seperated
# header means that the first line of the file are the headers
cdata<-read.csv2("Control_lion_T.csv", sep = ";", header = T, fill = T)
# remove the rows with NA in them
cdata <- cdata[-c(67, 68, 69), ]


# check for significance with parametric tests (GLMER)
# check for ashia
ashiadata1.1<-subset(cdata, Area=="Ashia")
glm30=glmer(ashiadata1.1$E_S_T~ashiadata1.1$Test_sound+(1|ashiadata1.1$Individual), family = poisson)
summary(glm30)
# no within individual effect of treatment within the captive area
# Thus when comparing the means of all individuals seperately within the captive area, 
# no significant difference between control and lion sound is present

# check for kuzuko
kuzukodata1.1<-subset(cdata, Area=="Kuzuko")
glm31=glmer(kuzukodata1.1$E_S_T~kuzukodata1.1$Test_sound+(1|kuzukodata1.1$Individual), family = poisson)
summary(glm31)
# a significant difference of treatment within the wild population is present
# P = 0.0069 where wild individuals end significantly further away when lion sound is played in comparison to control



# now also check for significance with non-paramatric tests 
# Kruskall wallis for the control vs lion difference
# mostly used when you have a low sample size (<20)

kruskal.test(E_S_T~Test_sound, data = ashiadata1.1)
# P = 0.964
# no significant differences between treatment within the captive population

kruskal.test(E_S_T~Test_sound, data = kuzukodata1.1)
# P = 0.0296 (<0.05)
# a significant difference between treatment within the captive population

